package Vimana::PortInstall;
use warnings;
use strict;
use Vimana::Util;
use Vimana::Logger;
use base qw/Class::Accessor::Fast/;
__PACKAGE__->mk_accessors( qw(package) );

sub run {
    my $self = shift;

}


1;
